@@ -24,7 +24,7 @@ manpage.1: manpage.sgml
   <!-- SECTION should be 1-8, maybe w/ subsection other parameters are
        allowed: see man(7), man(1). -->
   <!ENTITY dhsection   "<manvolnum>SECTION</manvolnum>">
-  <!ENTITY dhemail     "<email>nimnes@gmail.com</email>">
+  <!ENTITY dhemail     "<email>maemo-sensors@cs.karelia.ru</email>">
   <!ENTITY dhusername  "maemo-sensors">
   <!ENTITY dhucpackage "<refentrytitle>LIQUID</refentrytitle>">
   <!ENTITY dhpackage   "liquid">
