@@ -141,7 +141,7 @@ void MainWindow::showAbout() {
                 "<div style='y-overflow:scroll;'>"
                 "<strong>Version: %1</strong><br>"
                 "<strong>License: GPLv2</strong><br>"
-                "<strong>Homepage:</strong> <a href='http://liquid-graphic.garage.maemo.org'>link</a>
+                "<strong>Homepage: liquid-graphic.garage.maemo.org</strong>"
                 "<p>The <strong>%2</strong> is a graphic editor for Nokia's tablet. <br>"
                 "In our application user can controll a <br>"
                 "Brush, using accelerometer or touchscreen of a tablet. <br><br>"
